﻿'
' Copyright (c) 2021, MindFusion LLC - Bulgaria.
'


''' <summary>
''' Interaction logic for MainWindow.xaml
''' </summary>
Partial Public Class MainWindow
	Inherits Window
	Public Sub New()
		InitializeComponent()

		diagram.SelectAfterCreate = False

		' set colors
		diagram.BackBrush = New SolidColorBrush(Colors.Azure)

		Dim shapeStyle As New Style()
		shapeStyle.Setters.Add(New Setter(ShapeNode.BrushProperty, New LinearGradientBrush(Color.FromArgb(100, 255, 255, 255), Color.FromArgb(255, 0, 128, 192), 45)))
		shapeStyle.Setters.Add(New Setter(ShapeNode.EffectsSourceProperty, New List(Of NodeEffect)(New NodeEffect() {New GlassEffect()})))
		shapeStyle.Setters.Add(New Setter(ShapeNode.FontSizeProperty, 10.5))
		diagram.ShapeNodeStyle = shapeStyle

		Dim i As Integer = 0
		Dim hsize As Double = 85
		Dim vsize As Double = 93
		Dim perLine As Integer = 8

		' enum all predefined shapes
		For Each shape As Shape In Shape.Shapes
			' skip some arrowhead shapes that aren't that useful as node shapes
			If shape.Outline Is Nothing Then
				Continue For
			End If
			If shape Is ArrowHeads.RevWithCirc Then
				Continue For
			End If
			If shape Is ArrowHeads.DoubleArrow Then
				Continue For
			End If

			' create a node for this shape
			Dim node As ShapeNode = diagram.Factory.CreateShapeNode((i Mod perLine) * (hsize + 20) + 8, (i \ perLine) * (vsize + 60) + 15, hsize, vsize, shape)
			node.ToolTip = shape.Id
			node.Stroke = New SolidColorBrush(Colors.Black)

			' attach text below the box
			Dim label As ShapeNode = diagram.Factory.CreateShapeNode((i Mod perLine) * (hsize + 20) - 4, (i \ perLine) * (vsize + 60) + vsize + 15, hsize + 24, 30, Shapes.Rectangle)
			label.Text = If(shape.Id.StartsWith("Bpmn"), "Bpmn" & vbLf & shape.Id.Substring(4), shape.Id)
			label.Locked = True
			label.Transparent = True

			label.AttachTo(node, AttachToNode.BottomLeft)

			i = i + 1
		Next

		diagram.ResizeToFitItems(4, True)
	End Sub
End Class